summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gui/CMakeLists.txt3
-rw-r--r--gui/include/messages.hpp8
-rw-r--r--gui/tests/messages.cpp6
3 files changed, 9 insertions, 8 deletions
diff --git a/gui/CMakeLists.txt b/gui/CMakeLists.txt
index 928ff1a..799022d 100644
--- a/gui/CMakeLists.txt
+++ b/gui/CMakeLists.txt
@@ -144,6 +144,7 @@ install(TARGETS "gui")
add_executable("gui-tests"
"tests/gtk-test.cpp"
+ "tests/messages.cpp"
)
target_link_libraries("gui-tests" PRIVATE
@@ -152,5 +153,5 @@ target_link_libraries("gui-tests" PRIVATE
)
target_compile_definitions("resources" PUBLIC
- "TESTLOCALEDIR=\"${CMAKE_CURRENT_BINARY_DIR}/locale>\""
+ "TESTLOCALEDIR=\"${CMAKE_CURRENT_BINARY_DIR}/locale\""
) \ No newline at end of file
diff --git a/gui/include/messages.hpp b/gui/include/messages.hpp
index e29580b..9b8c315 100644
--- a/gui/include/messages.hpp
+++ b/gui/include/messages.hpp
@@ -3,10 +3,10 @@
* SPDX-License-Identifier: LGPL-2.1-only
*/
-#ifndef TURNS_LANG_MESSAGES_HPP
-#define TURNS_LANG_MESSAGES_HPP
+#ifndef TURNS_MESSAGES_HPP
+#define TURNS_MESSAGES_HPP
-namespace turns::lang
+namespace Turns::messages
{
auto constexpr static add_participant = "Add participant";
auto constexpr static cancel = "Cancel";
@@ -49,6 +49,6 @@ namespace turns::lang
auto constexpr static successfully_saved_format = "Successfully saved '{}'";
auto constexpr static turns = "Turns";
auto constexpr static turns_files = "Turns Files";
-} // namespace turns::lang
+} // namespace Turns::messages
#endif \ No newline at end of file
diff --git a/gui/tests/messages.cpp b/gui/tests/messages.cpp
index 6ff8936..c1d2f7e 100644
--- a/gui/tests/messages.cpp
+++ b/gui/tests/messages.cpp
@@ -3,7 +3,7 @@
* SPDX-License-Identifier: LGPL-2.1-only
*/
-#include "turns/lang/messages.hpp"
+#include "messages.hpp"
#include <catch2/catch_test_macros.hpp>
#include <catch2/generators/catch_generators.hpp>
@@ -14,7 +14,7 @@
#include <format>
#include <string>
-namespace turns::lang::tests
+namespace Turns::messages
{
TEST_CASE("Translated messages")
@@ -74,4 +74,4 @@ namespace turns::lang::tests
}
}
-} // namespace turns::lang::tests \ No newline at end of file
+} // namespace Turns::messages \ No newline at end of file